AllowedLayouts class

Specifies the document types to be scanned and optionally further specifies which types of layout are scanned per type.

Constructors

AllowedLayouts({List<String>? drivingLicense, List<String>? idFront, List<String>? insuranceCard, List<String>? mrz})
AllowedLayouts.fromJson(Map<String, dynamic> json)
factory
AllowedLayouts.fromRawJson(String str)
factory

Properties

drivingLicense List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idFront List<String>?
getter/setter pair
insuranceCard List<String>?
getter/setter pair
mrz List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited