barcodeFormats property
Set this to filter which barcode formats should be scanned. Setting 'ALL' will enable scanning all supported formats.
Implementation
List<BarcodeFormat>? barcodeFormats;
Set this to filter which barcode formats should be scanned. Setting 'ALL' will enable scanning all supported formats.
List<BarcodeFormat>? barcodeFormats;