consecutiveEqualResults property

bool? consecutiveEqualResults
getter/setter pair

DEPRECATED If this option is set, allows consecutive barcode results of the same barcode when scanning continuously.

Implementation

bool? consecutiveEqualResults;