disableAdvancedBarcode property
Sets whether or not to disable advanced barcode scanning even if the license supports it.
Implementation
bool? disableAdvancedBarcode;
Sets whether or not to disable advanced barcode scanning even if the license supports it.
bool? disableAdvancedBarcode;