parseAamva property
If this option is set, barcodes parsed according to the AAMVA standard. This only works for PDF417 codes on driving licenses.
Implementation
bool? parseAamva;
If this option is set, barcodes parsed according to the AAMVA standard. This only works for PDF417 codes on driving licenses.
bool? parseAamva;