BarcodeFormat enum

Inheritance
Available extensions

Values

ALL → const BarcodeFormat
AZTEC → const BarcodeFormat
AZTEC_INVERSE → const BarcodeFormat
BOOKLAND → const BarcodeFormat
CODABAR → const BarcodeFormat
CODE_11 → const BarcodeFormat
CODE_128 → const BarcodeFormat
CODE_32 → const BarcodeFormat
CODE_39 → const BarcodeFormat
CODE_93 → const BarcodeFormat
COUPON → const BarcodeFormat
DATABAR → const BarcodeFormat
DATA_MATRIX → const BarcodeFormat
DISCRETE_25 → const BarcodeFormat
DOT_CODE → const BarcodeFormat
EAN_13 → const BarcodeFormat
EAN_8 → const BarcodeFormat
GS1_128 → const BarcodeFormat
GS1_QR_CODE → const BarcodeFormat
ISBT_128 → const BarcodeFormat
ISSN_EAN → const BarcodeFormat
ITF → const BarcodeFormat
KIX → const BarcodeFormat
MATRIX_25 → const BarcodeFormat
MAXICODE → const BarcodeFormat
MICRO_PDF → const BarcodeFormat
MICRO_QR → const BarcodeFormat
MSI → const BarcodeFormat
ONE_D_INVERSE → const BarcodeFormat
PDF_417 → const BarcodeFormat
POST_UK → const BarcodeFormat
QR_CODE → const BarcodeFormat
QR_INVERSE → const BarcodeFormat
RSS_14 → const BarcodeFormat
RSS_EXPANDED → const BarcodeFormat
TRIOPTIC → const BarcodeFormat
UPC_A → const BarcodeFormat
UPC_E → const BarcodeFormat
UPC_EAN_EXTENSION → const BarcodeFormat
UPU_FICS → const BarcodeFormat
USPS_4_CB → const BarcodeFormat
US_PLANET → const BarcodeFormat
US_POSTNET → const BarcodeFormat

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeFormat>
A constant List of the values in this enum, in order of their declaration.