captureResolution property
The preferred resolution for video capture (720p, 1080p, 4K). This resolution is used to process images for scanning. 4K resolution is only supported for barcode scanning.
Implementation
String? captureResolution;
The preferred resolution for video capture (720p, 1080p, 4K). This resolution is used to process images for scanning. 4K resolution is only supported for barcode scanning.
String? captureResolution;