defaultCamera property

String? defaultCamera
getter/setter pair

Preferred camera to open: FRONT (front-facing), BACK (rear-facing), EXTERNAL (external rear), EXTERNAL_FRONT (external front), TELE (iOS-only; requests the telephoto lens and is honored only on devices that have one; on Android or on iOS devices without a tele lens BACK will be used), ULTRAWIDE (requests the ultra-wide lens and is honored only on devices that have one; on devices without an ultra-wide lens BACK will be used).

Implementation

String? defaultCamera;