enableFlipFramesLeftRight property

bool? enableFlipFramesLeftRight
getter/setter pair

(EXPERIMENTAL; Android-only) Mirrors the frame sideways (left-right) before it is processed, equivalent to a horizontal flip along the vertical axis. The camera preview on the screen is not affected. Disabled by default. NOTE: This has no effect when pluginConfig.barcodeConfig.fastProcessMode is true.

Implementation

bool? enableFlipFramesLeftRight;