enableTapToFocus property

bool? enableTapToFocus
getter/setter pair

Allow user to tap on the preview to focus the camera on a specific area of the screen (also known as tap-to-focus). Enabled by default.

Implementation

bool? enableTapToFocus;