zoomRatio property
The zoom ratio to apply to the camera. When set to a value greater than 0, this property takes precedence over defaultCamera for determining which physical lens to use. For example, setting zoomRatio to 0.5 on a device with an ultra-wide lens will select that lens, regardless of the defaultCamera setting. A value of 0 means no zoom ratio is applied and the camera selection falls back to defaultCamera.
Implementation
double? zoomRatio;