ContainerConfig class

Configuration for scanning shipping container numbers

Constructors

ContainerConfig({int? minConfidence, ContainerConfigScanMode? scanMode, String? validationRegex})
ContainerConfig.fromJson(Map<String, dynamic> json)
factory
ContainerConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minConfidence int?
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMode ContainerConfigScanMode?
Determines if container numbers shall be scanned horizontally or vertically.
getter/setter pair
validationRegex String?
Sets a regular expression which the scanned text needs to match in order to trigger a scan result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited