cropOffset property
Adjusts the captured region position in camera pixels (px) after cropPadding is applied. Positive x shifts right, positive y shifts down.
Implementation
Offset? cropOffset;
Adjusts the captured region position in camera pixels (px) after cropPadding is applied. Positive x shifts right, positive y shifts down.
Offset? cropOffset;