ratioFromSize property

RatioFromSize? ratioFromSize
getter/setter pair

A size constraining the ratio of width / height. If set to 0, the ratio will be equal to the full frame. For the optimal ratio for each technical capability have a look at the Technical Capabilities section at documentation.anyline.com.

Implementation

RatioFromSize? ratioFromSize;