strokeWidth property
The stroke width of the cutout border in density-independent pixels (dp). If set to 0, the line will be invisible.
Implementation
int? strokeWidth;
The stroke width of the cutout border in density-independent pixels (dp). If set to 0, the line will be invisible.
int? strokeWidth;