width property
The preferred width in pixels, relating to the camera resolution. If not specified or 0, the maximum possible width will be chosen.
Implementation
int? width;
The preferred width in pixels, relating to the camera resolution. If not specified or 0, the maximum possible width will be chosen.
int? width;