LayoutInsuranceCard class

Contains all the supported field scan options for insurance cards.

Constructors

LayoutInsuranceCard({UniversalIdField? authority, UniversalIdField? dateOfBirth, UniversalIdField? dateOfExpiry, UniversalIdField? documentNumber, UniversalIdField? firstName, UniversalIdField? lastName, UniversalIdField? nationality, UniversalIdField? personalNumber})
LayoutInsuranceCard.fromJson(Map<String, dynamic> json)
factory
LayoutInsuranceCard.fromRawJson(String str)
factory

Properties

authority UniversalIdField?
getter/setter pair
dateOfBirth UniversalIdField?
getter/setter pair
dateOfExpiry UniversalIdField?
getter/setter pair
documentNumber UniversalIdField?
getter/setter pair
firstName UniversalIdField?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName UniversalIdField?
getter/setter pair
nationality UniversalIdField?
getter/setter pair
personalNumber UniversalIdField?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited