LayoutVehicleRegistrationCertificate class

Contains all the supported field scan options for vehicle registration certificates.

Properties

address VehicleRegistrationCertificateField?
The Address Field
getter/setter pair
brand VehicleRegistrationCertificateField?
The Brand Field
getter/setter pair
displacement VehicleRegistrationCertificateField?
The Displacement Field
getter/setter pair
documentNumber VehicleRegistrationCertificateField?
The DocumentNumber Field
getter/setter pair
firstIssued VehicleRegistrationCertificateField?
The FirstIssued Field
getter/setter pair
firstName VehicleRegistrationCertificateField?
The FirstName Field
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName VehicleRegistrationCertificateField?
The LastName Field
getter/setter pair
licensePlate VehicleRegistrationCertificateField?
The LicensePlate Field
getter/setter pair
manufacturerCode VehicleRegistrationCertificateField?
The ManufacturerCode Field
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tire VehicleRegistrationCertificateField?
The Tire Field
getter/setter pair
vehicleIdentificationNumber VehicleRegistrationCertificateField?
The VehicleIdentificationNumber Field
getter/setter pair
vehicleType VehicleRegistrationCertificateField?
The VehicleType Field
getter/setter pair
vehicleTypeCode VehicleRegistrationCertificateField?
The VehicleTypeCode Field
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited