LicensePlateConfig class

Configuration for scanning license plates

Constructors

LicensePlateConfig({int? minConfidence, LicensePlateConfigScanMode? scanMode, String? validationRegex, VehicleInspectionSticker? vehicleInspectionSticker})
LicensePlateConfig.fromJson(Map<String, dynamic> json)
factory
LicensePlateConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minConfidence int?
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMode LicensePlateConfigScanMode?
Specifies a country or location of which license plates shall be scanned.
getter/setter pair
validationRegex String?
Sets a regular expression per country. Expected format: "'country_code':^regex$, 'other_country_code':^other_regex$". The country code needs to be provided in the international vehicle registration code format that is visible on the license plate (for example 'A' for Austria). Note: not available for the scanModes unitedstates and africa.
getter/setter pair
vehicleInspectionSticker VehicleInspectionSticker?
Select if the visual inspection sticker should be scanned. If OPTIONAL, the visual inspection sticker will only be returned if found successfully. If MANDATORY the scan will only return if found successfully. Not available on africa and unitedstates.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited