validationRegex property

String? validationRegex
getter/setter pair

Sets a regular expression per country. Expected format: "'country_code':^regex$, 'other_country_code':^other_regex$". The country code needs to be provided in the international vehicle registration code format that is visible on the license plate (for example 'A' for Austria). Note: not available for the scanModes unitedstates and africa.

Implementation

String? validationRegex;