MeterConfig class

Configuration for scanning meters

Constructors

MeterConfig({int? maxNumDecimalDigits, int? minConfidence, MeterConfigScanMode? scanMode, String? validationRegex})
MeterConfig.fromJson(Map<String, dynamic> json)
factory
MeterConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxNumDecimalDigits int?
Defines the maximum number of read decimal digits for values >=0. Negative values mean all decimal digits are read. Currently implemented only for the "auto_analog_digital_meter" scan mode.
getter/setter pair
minConfidence int?
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMode MeterConfigScanMode?
Determines which types of meters to scan.
getter/setter pair
validationRegex String?
Sets a regular expression which the scanned text needs to match in order to trigger a scan result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited