cropAndTransformId property
The cropAndTransformID determines whether or not the image shall be cropped and transformed.
Implementation
bool? cropAndTransformId;
The cropAndTransformID determines whether or not the image shall be cropped and transformed.
bool? cropAndTransformId;