mrzFieldScanOptions property
The fieldmrzScanOptions configure which text fields shall be captured mandatory, optional or not at all.
Implementation
MrzFieldScanOptions? mrzFieldScanOptions;
The fieldmrzScanOptions configure which text fields shall be captured mandatory, optional or not at all.
MrzFieldScanOptions? mrzFieldScanOptions;