strictMode property

bool? strictMode
getter/setter pair

When enabling the strictMode, a result is only returned if all the check digits on the scanned document are valid.

Implementation

bool? strictMode;