MrzScanOption enum

The scanOption determines whether a field is considered optional, mandatory, disabled or follows a default behavior. Default behavior is one of the other three that yields the best recall results with all layouts enabled.

The mrzScanOption determines whether a field is considered optional, mandatory, disabled or follows a default behavior.

Inheritance
Available extensions

Values

DEFAULT → const MrzScanOption
DISABLED → const MrzScanOption
MANDATORY → const MrzScanOption
OPTIONAL → const MrzScanOption

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MrzScanOption>
A constant List of the values in this enum, in order of their declaration.