charPaddingXFactor property
Defines the average horizontal distance between two characters in 'grid' mode, measured in percentage of the characters width.
Implementation
double? charPaddingXFactor;
Defines the average horizontal distance between two characters in 'grid' mode, measured in percentage of the characters width.
double? charPaddingXFactor;