charPaddingYFactor property
Defines the average vertical distance between two characters in 'grid' mode, measured in percentage of the characters height.
Implementation
double? charPaddingYFactor;
Defines the average vertical distance between two characters in 'grid' mode, measured in percentage of the characters height.
double? charPaddingYFactor;