OdometerConfig class

Configuration for scanning odometers

Constructors

OdometerConfig({int? minConfidence, String? validationRegex})
OdometerConfig.fromJson(Map<String, dynamic> json)
factory
OdometerConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minConfidence int?
Sets a minimum confidence which has to be reached in order to trigger a scan result.The value has to be between 0 and 100. Defaults to 60.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationRegex String?
Sets a regular expression which the scanned text needs to match in order to trigger a scan result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited