validationRegex property
Sets a regular expression which the scanned text needs to match in order to trigger a scan result.
Implementation
String? validationRegex;
Sets a regular expression which the scanned text needs to match in order to trigger a scan result.
String? validationRegex;