OverlayDimensionConfig class

Sets the offset dimension of the overlay.

Sets the dimension of the overlay.

Sets the size dimension of the overlay.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleX OverlayScaleConfig?
Sets the scale for x axis of the overlay.
getter/setter pair
scaleY OverlayScaleConfig?
Sets the scale for y axis of the overlay.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited