OverlayScaleConfig class

Sets the scale for x axis of the overlay.

Configuration for UI Feedback overlays

Sets the scale for y axis of the overlay.

Constructors

OverlayScaleConfig({OverlayScaleTypeConfig? scaleType, double? scaleValue})
OverlayScaleConfig.fromJson(Map<String, dynamic> json)
factory
OverlayScaleConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleType OverlayScaleTypeConfig?
Sets the scale type of the overlay.
getter/setter pair
scaleValue double?
Sets the scale value of the overlay.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited