PluginConfig class

General configuration for scan plugins

Constructors

PluginConfig({BarcodeConfig? barcodeConfig, bool? cancelOnResult, CommercialTireIdConfig? commercialTireIdConfig, int? consecutiveEqualResultFilter, ContainerConfig? containerConfig, String? id, JapaneseLandingPermissionConfig? japaneseLandingPermissionConfig, LicensePlateConfig? licensePlateConfig, MeterConfig? meterConfig, MrzConfig? mrzConfig, OcrConfig? ocrConfig, OdometerConfig? odometerConfig, int? startScanDelay, List<StartVariable>? startVariables, TinConfig? tinConfig, TireMakeConfig? tireMakeConfig, TireSizeConfig? tireSizeConfig, UniversalIdConfig? universalIdConfig, VehicleRegistrationCertificateConfig? vehicleRegistrationCertificateConfig, VinConfig? vinConfig})
PluginConfig.fromJson(Map<String, dynamic> json)
factory
PluginConfig.fromRawJson(String str)
factory

Properties

barcodeConfig BarcodeConfig?
getter/setter pair
cancelOnResult bool?
Sets whether or not to continue scanning once a result is found.
getter/setter pair
commercialTireIdConfig CommercialTireIdConfig?
getter/setter pair
consecutiveEqualResultFilter int?
This option allows to finetune the handling results of the same content when scanning continuously. If the option is set to -1, equal results will not be reported again until the scanning process is stopped. Setting this option to 0 will report equal results every time it is found. Setting this option to greater than 0 indicates how much time (milliseconds) must pass by not detecting the result before it will be detected again. (This feature is currently only supported in Barcode scanning)
getter/setter pair
containerConfig ContainerConfig?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Sets a name for the scan plugin.
getter/setter pair
japaneseLandingPermissionConfig JapaneseLandingPermissionConfig?
getter/setter pair
licensePlateConfig LicensePlateConfig?
getter/setter pair
meterConfig MeterConfig?
getter/setter pair
mrzConfig MrzConfig?
getter/setter pair
ocrConfig OcrConfig?
getter/setter pair
odometerConfig OdometerConfig?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startScanDelay int?
Sets an initial time period (in milliseconds) where scanned frames are not processed as results.
getter/setter pair
startVariables List<StartVariable>?
Allows to fine-tune a list of options for plugins.
getter/setter pair
tinConfig TinConfig?
getter/setter pair
tireMakeConfig TireMakeConfig?
getter/setter pair
tireSizeConfig TireSizeConfig?
getter/setter pair
universalIdConfig UniversalIdConfig?
getter/setter pair
vehicleRegistrationCertificateConfig VehicleRegistrationCertificateConfig?
getter/setter pair
vinConfig VinConfig?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited