RatioFromSize class

A size constraining the ratio of width / height. If set to 0, the ratio will be equal to the full frame. For the optimal ratio for each technical capability have a look at the Technical Capabilities section at documentation.anyline.com.

Constructors

RatioFromSize({double? height, double? width})
RatioFromSize.fromJson(Map<String, dynamic> json)
factory
RatioFromSize.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited