RunSkippedWhen class

Configuration for triggering UI Feedback on RunSkipped events

Constructors

RunSkippedWhen({UiFeedbackElementAttributesConfig? applyAttributesInstead, UiFeedbackElementContentConfig? applyContentInstead, bool? applyDefaultAttributes, bool? applyDefaultContent, int? codeEquals})
RunSkippedWhen.fromJson(Map<String, dynamic> json)
factory
RunSkippedWhen.fromRawJson(String str)
factory

Properties

applyAttributesInstead UiFeedbackElementAttributesConfig?
getter/setter pair
applyContentInstead UiFeedbackElementContentConfig?
getter/setter pair
applyDefaultAttributes bool?
Sets whether the trigger must apply defaultAttributes.
getter/setter pair
applyDefaultContent bool?
Sets whether the trigger must apply defaultContent.
getter/setter pair
codeEquals int?
Sets the runSkipped code to be watched.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited