ScanFeedbackConfig class

Schema for SDK ScanFeedback Configuration

Constructors

ScanFeedbackConfig({ScanFeedbackConfigAnimation? animation, int? animationDuration, bool? beepOnResult, bool? blinkAnimationOnResult, int? cornerRadius, String? fillColor, int? redrawTimeout, String? strokeColor, int? strokeWidth, Style? style, bool? vibrateOnResult})
ScanFeedbackConfig.fromJson(Map<String, dynamic> json)
factory
ScanFeedbackConfig.fromRawJson(String str)
factory

Properties

animation ScanFeedbackConfigAnimation?
The animation style of the feedback.
getter/setter pair
animationDuration int?
The duration of the animation in milliseconds.
getter/setter pair
beepOnResult bool?
If true, make a beep sound when a result is found.
getter/setter pair
blinkAnimationOnResult bool?
If true, flash the view when a result is found.
getter/setter pair
cornerRadius int?
The corner radius in density-independent pixels (dp).
getter/setter pair
fillColor String?
The fill color.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
redrawTimeout int?
The timeout to redraw the visual feedback in milliseconds.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor String?
The stroke color.
getter/setter pair
strokeWidth int?
The stroke width in density-independent pixels (dp).
getter/setter pair
style Style?
The style of the feedback.
getter/setter pair
vibrateOnResult bool?
If true, vibrate the device when a result is found.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited