ScanInfoWhen class

Configuration for triggering UI Feedback on ScanInfo events

Constructors

ScanInfoWhen({UiFeedbackElementAttributesConfig? applyAttributesInstead, UiFeedbackElementContentConfig? applyContentInstead, bool? applyDefaultAttributes, bool? applyDefaultContent, String? varNameEquals, String? varValueEquals})
ScanInfoWhen.fromJson(Map<String, dynamic> json)
factory
ScanInfoWhen.fromRawJson(String str)
factory

Properties

applyAttributesInstead UiFeedbackElementAttributesConfig?
getter/setter pair
applyContentInstead UiFeedbackElementContentConfig?
getter/setter pair
applyDefaultAttributes bool?
Sets whether the trigger must apply defaultAttributes.
getter/setter pair
applyDefaultContent bool?
Sets whether the trigger must apply defaultContent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
varNameEquals String?
Sets the ScanInfo variable name to be watched.
getter/setter pair
varValueEquals String?
Sets the ScanInfo variable value to be watched.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited