ScanViewConfiguration class

Schema for SDK JSON configurations

Constructors

ScanViewConfiguration({CameraConfig? cameraConfig, FlashConfig? flashConfig, Map<String, dynamic>? options, String? scanViewConfigDescription, ViewPluginCompositeConfig? viewPluginCompositeConfig, ViewPluginConfig? viewPluginConfig})
ScanViewConfiguration.fromJson(Map<String, dynamic> json)
factory
ScanViewConfiguration.fromRawJson(String str)
factory

Properties

cameraConfig CameraConfig?
getter/setter pair
flashConfig FlashConfig?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
options Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanViewConfigDescription String?
An optional description for the entire ScanView configuration.
getter/setter pair
viewPluginCompositeConfig ViewPluginCompositeConfig?
getter/setter pair
viewPluginConfig ViewPluginConfig?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited