StartVariable class

Describes a start variable for fine-tuning plugins.

Constructors

StartVariable({String? key, dynamic value})
StartVariable.fromJson(Map<String, dynamic> json)
factory
StartVariable.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
The key of the variable.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
The value of the variable.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited