TinConfig class

Configuration for scanning TIN numbers

Constructors

TinConfig({double? detectionMinHeightRatio, double? horizontalAlignmentRatio, int? minConfidence, TinConfigScanMode? scanMode, UpsideDownMode? upsideDownMode, bool? validateProductionDate, String? validationRegex})
TinConfig.fromJson(Map<String, dynamic> json)
factory
TinConfig.fromRawJson(String str)
factory

Properties

detectionMinHeightRatio double?
Defines the minimum height ratio relative to image height for the detected text region. Ensures the device is close enough to the tire by requiring detected text to meet a minimum height requirement. Higher values are more restrictive (text must be taller, meaning device must be closer). This parameter helps prevent premature scans when the user is too far away and ensures better image quality.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
horizontalAlignmentRatio double?
Defines the horizontal ratio for text alignment checks relative to image width. Ensures the detected TIN text starts near the left edge of the cutout (or right edge when upside-down) to prevent partial captures. Lower values are more restrictive (text must be closer to the edge). This parameter helps reduce premature results and ensures proper text alignment.
getter/setter pair
minConfidence int?
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMode TinConfigScanMode?
Sets the mode to scan universal TIN numbers ('UNIVERSAL') or TIN numbers of any length starting with DOT ('DOT').
getter/setter pair
upsideDownMode UpsideDownMode?
Sets whether the text shall also be scanned upside-down.
getter/setter pair
validateProductionDate bool?
Sets whether the production date validation is enabled. If it is set to false the scan result is also returned for invalid and missing dates.
getter/setter pair
validationRegex String?
Sets a regular expression which the TIN text needs to match in order to trigger a scan result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited