validationRegex property
Sets a regular expression which the TIN text needs to match in order to trigger a scan result.
Implementation
String? validationRegex;
Sets a regular expression which the TIN text needs to match in order to trigger a scan result.
String? validationRegex;