validationRegex property

String? validationRegex
getter/setter pair

Sets a regular expression which the tire make text needs to match in order to trigger a scan result. E.g. "(Continental|Dunlop)" will only trigger on Continental or Dunlop tires.

Implementation

String? validationRegex;