UiFeedbackConfig class
General configuration for UI Feedback elements
Constructors
-
UiFeedbackConfig({List<
UiFeedbackElementConfig> ? elements, List<UiFeedbackPresetDefinitionConfig> ? presetDefinitions, List<UiFeedbackPresetConfig> ? presets}) -
UiFeedbackConfig.fromJson(Map<
String, dynamic> json) -
factory
- UiFeedbackConfig.fromRawJson(String str)
-
factory
Properties
-
elements
↔ List<
UiFeedbackElementConfig> ? -
Elements inside UIFeedbackConfig.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
presetDefinitions
↔ List<
UiFeedbackPresetDefinitionConfig> ? -
Preset definitions inside UIFeedbackConfig.
getter/setter pair
-
presets
↔ List<
UiFeedbackPresetConfig> ? -
Allows to use presets.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited