UiFeedbackElementAttributesConfig class

Configuration attributes for UI Feedback view elements

Constructors

UiFeedbackElementAttributesConfig({String? backgroundColor, ImageScaleType? imageScaleType, TextAlignment? textAlignment, String? textColor})
UiFeedbackElementAttributesConfig.fromJson(Map<String, dynamic> json)
factory
UiFeedbackElementAttributesConfig.fromRawJson(String str)
factory

Properties

backgroundColor String?
Sets the background color.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageScaleType ImageScaleType?
Sets the image scale type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlignment TextAlignment?
Sets the text alignment.
getter/setter pair
textColor String?
Sets the text color.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited