UiFeedbackElementConfig class

Configuration for uiFeedback element

Properties

clickable bool?
Sets whether the view is clickable.
getter/setter pair
contentType ContentTypeEnum?
getter/setter pair
defaultAttributes UiFeedbackElementAttributesConfig?
getter/setter pair
defaultContent UiFeedbackElementContentConfig?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Sets the id of the element.
getter/setter pair
overlay OverlayConfig?
getter/setter pair
presets List<UiFeedbackPresetConfig>?
Allows to use element presets.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
Sets a tag for the element.
getter/setter pair
trigger UiFeedbackElementTriggerConfig?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited