UiFeedbackElementContentConfig class

Configuration for UI Feedback content

Constructors

UiFeedbackElementContentConfig({String? contentValue, int? durationMills, int? priorityLevel})
UiFeedbackElementContentConfig.fromJson(Map<String, dynamic> json)
factory
UiFeedbackElementContentConfig.fromRawJson(String str)
factory

Properties

contentValue String?
Sets the content of the element.
getter/setter pair
durationMills int?
Sets the duration of the element.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
priorityLevel int?
Sets the priority of the element.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited