UiFeedbackElementTriggerConfig class

Trigger configuration for UI Feedback

Properties

hashCode int
The hash code for this object.
no setterinherited
presets List<UiFeedbackPresetConfig>?
getter/setter pair
runSkipped List<UiFeedbackElementTriggerWhenRunSkippedConfig>?
Allows to watch runSkipped events.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanInfo List<UiFeedbackElementTriggerWhenScanInfoConfig>?
Allows to watch scanInfo events.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited