UiFeedbackElementTriggerWhenRunSkippedConfig class
Configuration for triggering UI Feedback on RunSkipped events
Constructors
- UiFeedbackElementTriggerWhenRunSkippedConfig({RunSkippedWhen? when})
-
UiFeedbackElementTriggerWhenRunSkippedConfig.fromJson(Map<
String, dynamic> json) -
factory
- UiFeedbackElementTriggerWhenRunSkippedConfig.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- when ↔ RunSkippedWhen?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited