UiFeedbackPresetAttributeConfig class

Configuration for uiFeedback preset attribute.

Constructors

UiFeedbackPresetAttributeConfig({String? attributeName, String? attributeValue})
UiFeedbackPresetAttributeConfig.fromJson(Map<String, dynamic> json)
factory
UiFeedbackPresetAttributeConfig.fromRawJson(String str)
factory

Properties

attributeName String?
Name of the attribute declared in the preset definition.
getter/setter pair
attributeValue String?
Sets the value of the attribute.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited