UiFeedbackPresetConfig class
Configuration for uiFeedback preset.
Constructors
-
UiFeedbackPresetConfig({List<
UiFeedbackPresetAttributeConfig> ? presetAttributes, String? presetName}) -
UiFeedbackPresetConfig.fromJson(Map<
String, dynamic> json) -
factory
- UiFeedbackPresetConfig.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
presetAttributes
↔ List<
UiFeedbackPresetAttributeConfig> ? -
Attributes inside preset.
getter/setter pair
- presetName ↔ String?
-
Name of the preset.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited