UiFeedbackPresetDefinitionAttributeConfig class

Configuration for uiFeedback preset definition attribute.

Properties

elementName String?
Sets the name of the element of the attribute.
getter/setter pair
elementType ElementTypeEnum?
Sets the preset definition attribute element type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Sets the name of the attribute.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited