allowedLayouts property

AllowedLayouts? allowedLayouts
getter/setter pair

Specifies the document types to be scanned and optionally further specifies which types of layout are scanned per type.

Implementation

AllowedLayouts? allowedLayouts;