UniversalIdField class

Configures scanning options for ID fields in order to fine-tune the ID scanner.

Constructors

UniversalIdField({int? minConfidence, MrzScanOption? scanOption})
UniversalIdField.fromJson(Map<String, dynamic> json)
factory
UniversalIdField.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minConfidence int?
Set the minConfidence which has to be reached in order to trigger a scan result. The value has to be between 0 and 100. Defaults to 60.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanOption MrzScanOption?
The scanOption determines whether a field is considered optional, mandatory, disabled or follows a default behavior. Default behavior is one of the other three that yields the best recall results with all layouts enabled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited