scanOption property

MrzScanOption? scanOption
getter/setter pair

The scanOption determines whether a field is considered optional, mandatory, disabled or follows a default behavior. Default behavior is one of the other three that yields the best recall results with all layouts enabled.

Implementation

MrzScanOption? scanOption;