ViewPluginCompositeConfig class

Schema for SDK ViewPlugin Configuration

Constructors

ViewPluginCompositeConfig({String? id, ProcessingMode? processingMode, List<ViewPlugin>? viewPlugins})
ViewPluginCompositeConfig.fromJson(Map<String, dynamic> json)
factory
ViewPluginCompositeConfig.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The ID (name) of the workflow.
getter/setter pair
processingMode ProcessingMode?
The processing mode of the workflow (parallel, sequential, parallelFirstScan).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewPlugins List<ViewPlugin>?
The ordered list of viewPlugins, each as JSON object with a given viewPluginConfig.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited