validateCheckDigit property
Setting this to 'true' will enforce checking the check digit and only return results if it is correct.
Implementation
bool? validateCheckDigit;
Setting this to 'true' will enforce checking the check digit and only return results if it is correct.
bool? validateCheckDigit;