Aamva class

Holds all encoded barcode information according to the AAMVA standard

Constructors

Aamva({int? aamvaVersion, BodyPart? bodyPart})
Aamva.fromJson(Map<String, dynamic> json)
factory
Aamva.fromRawJson(String str)
factory

Properties

aamvaVersion ↔ int?
getter/setter pair
bodyPart ↔ BodyPart?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited