AndroidScanViewAttributesConfig class

Android-specific ScanView attributes for layout and behavior customization.

Android ScanView attributes config

Constructors

AndroidScanViewAttributesConfig({bool? enableCameraPermissionHandling, bool? useCameraX})
AndroidScanViewAttributesConfig.fromJson(Map<String, dynamic> json)
factory
AndroidScanViewAttributesConfig.fromRawJson(String str)
factory

Properties

enableCameraPermissionHandling bool?
Enable or disable camera permission handling from ScanView loading process.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useCameraX bool?
Enable or disable usage of CameraX API instead of Camera1 API. Default is true.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited