Area enum

The area information

Inheritance
Available extensions

Values

ALABAMA → const Area
ALASKA → const Area
ALBERTA → const Area
AMERICAN_SAMOA → const Area
ARIZONA → const Area
ARKANSAS → const Area
BRITISH_COLUMBIA → const Area
CALIFORNIA → const Area
COLORADO → const Area
CONNECTICUT → const Area
DELAWARE → const Area
DISTRICT_OF_COLUMBIA → const Area
FLORIDA → const Area
GEORGIA → const Area
GUAM → const Area
HAWAII → const Area
IDAHO → const Area
ILLINOIS → const Area
INDIANA → const Area
IOWA → const Area
KANSAS → const Area
KENTUCKY → const Area
LOUISIANA → const Area
MAINE → const Area
MANITOBA → const Area
MARYLAND → const Area
MASSACHUSETTS → const Area
MICHIGAN → const Area
MINNESOTA → const Area
MISSISSIPPI → const Area
MISSOURI → const Area
MONTANA → const Area
NEBRASKA → const Area
NEVADA → const Area
NEW_BRUNSWICK → const Area
NEW_HAMPSHIRE → const Area
NEW_JERSEY → const Area
NEW_MEXICO → const Area
NEW_YORK → const Area
NORTH_CAROLINA → const Area
NORTH_DAKOTA → const Area
NOVA_SCOTIA → const Area
OHIO → const Area
OKLAHOMA → const Area
ONTARIO → const Area
OREGON → const Area
PENNSYLVANIA → const Area
PUERTO_RICO → const Area
QUEBEC → const Area
RHODE_ISLAND → const Area
SASKATCHEWAN → const Area
SOUTH_CAROLINA → const Area
SOUTH_DAKOTA → const Area
TENNESSEE → const Area
TEXAS → const Area
UTAH → const Area
VERMONT → const Area
VIRGINIA → const Area
WASHINGTON → const Area
WEST_VIRGINIA → const Area
WISCONSIN → const Area
WYOMING → const Area

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Area>
A constant List of the values in this enum, in order of their declaration.