Barcode class

Describes barcode information

Constructors

Barcode({Aamva? aamva, String? base64Value, List<int>? coordinates, String? format, String? value})
Barcode.fromJson(Map<String, dynamic> json)
factory
Barcode.fromRawJson(String str)
factory

Properties

aamva Aamva?
getter/setter pair
base64Value String?
Contains the base64-encoded value
getter/setter pair
coordinates List<int>?
Corner points of a polygon surrounding the discovered barcode, starting from the bottom-left coordinate going counter-clockwise. The coordinates are in reference to the image of the plugin result.
getter/setter pair
format String?
The barcode format
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
The value of the barcode
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited