coordinates property

List<int>? coordinates
getter/setter pair

Corner points of a polygon surrounding the discovered barcode, starting from the bottom-left coordinate going counter-clockwise. The coordinates are in reference to the image of the plugin result.

Implementation

List<int>? coordinates;