BarcodeResult class

Describes result information of scanning barcodes

Constructors

BarcodeResult({List<Barcode>? barcodes})
BarcodeResult.fromJson(Map<String, dynamic> json)
factory
BarcodeResult.fromRawJson(String str)
factory

Properties

barcodes List<Barcode>?
Contains a list of one or more barcodes found on the processed image
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited