ContainerResult class

Describes result information of scanning shipping containers

Constructors

ContainerResult({String? text})
ContainerResult.fromJson(Map<String, dynamic> json)
factory
ContainerResult.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text value of the shipping container
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited