CropRect class

The rect information of the region that was processed within the image

Constructors

CropRect({int? height, int? width, int? x, int? y})
CropRect.fromJson(Map<String, dynamic> json)
factory
CropRect.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int?
The height
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
The width
getter/setter pair
x int?
The X value
getter/setter pair
y int?
The Y value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited