DateValue class

Describes the date value of an ID field

Constructors

DateValue({int? confidence, int? day, String? formattedText, int? month, String? text, int? year})
DateValue.fromJson(Map<String, dynamic> json)
factory
DateValue.fromRawJson(String str)
factory

Properties

confidence ↔ int?
The confidence value
getter/setter pair
day ↔ int?
The day
getter/setter pair
formattedText ↔ String?
The formatted text value
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
month ↔ int?
The month
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text value
getter/setter pair
year ↔ int?
The year
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited