imageContainer property
Specifies how and where the scan result images are delivered.
Implementation
ExportedScanResultImageContainer? imageContainer;
Specifies how and where the scan result images are delivered.
ExportedScanResultImageContainer? imageContainer;