imageParameters property
Output format and quality settings applied to all images exported with this scan result.
Implementation
ExportedScanResultImageParameters? imageParameters;
Output format and quality settings applied to all images exported with this scan result.
ExportedScanResultImageParameters? imageParameters;