ExportedScanResultImageContainerEncoded class

Deliver images as base64-encoded strings embedded in the result JSON.

Image container that encodes scan result images as base64 strings in the result JSON.

Properties

hashCode int
The hash code for this object.
no setterinherited
images ExportedScanResultImages?
The base64-encoded image data for each image type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited