ExportedScanResultImageContainerSaved class

Deliver images as files saved to the specified directory path.

Image container that saves scan result images to a local file path.

Properties

hashCode int
The hash code for this object.
no setterinherited
images ExportedScanResultImages?
The image filenames saved in the specified path.
getter/setter pair
path String?
Directory path where scan result images are saved.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited