JlpResult class

Yields field information of a japanese landing permission ticket

Properties

airport JapaneseLandingPermissionResultField?
getter/setter pair
dateOfExpiry JapaneseLandingPermissionResultField?
getter/setter pair
dateOfIssue JapaneseLandingPermissionResultField?
getter/setter pair
duration JapaneseLandingPermissionResultField?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status JapaneseLandingPermissionResultField?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited