Latin class

The text parameters

Constructors

Latin({int? confidence, String? text})
Latin.fromJson(Map<String, dynamic> json)
factory
Latin.fromRawJson(String str)
factory

Properties

confidence int?
The confidence value
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited