LicensePlateResult class

Describes result information of scanning license plates

Constructors

LicensePlateResult({Area? area, String? country, String? plateText, bool? vehicleInspectionFound, String? vehicleInspectionMonth, bool? vehicleInspectionValid, String? vehicleInspectionYear})
LicensePlateResult.fromJson(Map<String, dynamic> json)
factory
LicensePlateResult.fromRawJson(String str)
factory

Properties

area Area?
The area information
getter/setter pair
country String?
The country information
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
plateText String?
The plate text
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vehicleInspectionFound bool?
(Optional) If vehicleInspectionSticker config is OPTIONAL, this is true if a Visual Inspection Sticker was found, false otherwise. If the config is MANDATORY, this field is always true.
getter/setter pair
vehicleInspectionMonth String?
(Optional) The month depicted on the Visual Inspection Sticker.
getter/setter pair
vehicleInspectionValid bool?
(Optional) This is true, if the Visual Inspection Sticker depicts a date in the future.
getter/setter pair
vehicleInspectionYear String?
(Optional) The year depicted on the Visual Inspection Sticker.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited