vehicleInspectionValid property
(Optional) This is true, if the Visual Inspection Sticker depicts a date in the future.
Implementation
bool? vehicleInspectionValid;
(Optional) This is true, if the Visual Inspection Sticker depicts a date in the future.
bool? vehicleInspectionValid;