MrzResult class
Describes result information of scanning MRZ
Constructors
- MrzResult({bool? allCheckDigitsValid, String? checkDigitDateOfBirth, String? checkDigitDateOfExpiry, String? checkDigitDocumentNumber, String? checkDigitFinal, String? checkDigitPersonalNumber, String? dateOfBirth, String? dateOfBirthObject, String? dateOfExpiry, String? dateOfExpiryObject, String? documentNumber, String? documentType, FieldConfidences? fieldConfidences, String? firstName, String? givenNames, String? issuingCountryCode, String? lastName, String? mrzString, String? nationalityCountryCode, String? optionalData, String? personalNumber, String? sex, String? surname, String? vizAddress, String? vizDateOfBirth, String? vizDateOfBirthObject, String? vizDateOfExpiry, String? vizDateOfExpiryObject, String? vizDateOfIssue, String? vizDateOfIssueObject, String? vizGivenNames, String? vizSurname})
-
MrzResult.fromJson(Map<
String, dynamic> json) -
factory
- MrzResult.fromRawJson(String str)
-
factory
Properties
- allCheckDigitsValid ↔ bool?
-
True if all check digits are valid
getter/setter pair
- checkDigitDateOfBirth ↔ String?
-
The CheckDigitDateOfBirth
getter/setter pair
- checkDigitDateOfExpiry ↔ String?
-
The CheckDigitDateOfExpiry
getter/setter pair
- checkDigitDocumentNumber ↔ String?
-
The CheckDigitDocumentNumber
getter/setter pair
- checkDigitFinal ↔ String?
-
The CheckDigitFinal
getter/setter pair
- checkDigitPersonalNumber ↔ String?
-
The CheckDigitPersonalNumber
getter/setter pair
- dateOfBirth ↔ String?
-
The DateOfBirth
getter/setter pair
- dateOfBirthObject ↔ String?
-
The DateOfBirthObject
getter/setter pair
- dateOfExpiry ↔ String?
-
The DateOfExpiry
getter/setter pair
- dateOfExpiryObject ↔ String?
-
The DateOfExpiryObject
getter/setter pair
- documentNumber ↔ String?
-
The DocumentNumber
getter/setter pair
- documentType ↔ String?
-
The DocumentType
getter/setter pair
- fieldConfidences ↔ FieldConfidences?
-
The confidence values of each field
getter/setter pair
- firstName ↔ String?
-
The FirstName
getter/setter pair
- givenNames ↔ String?
-
The GivenNames
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuingCountryCode ↔ String?
-
The IssuingCountryCode
getter/setter pair
- lastName ↔ String?
-
The LastName
getter/setter pair
- mrzString ↔ String?
-
The MRZString
getter/setter pair
- nationalityCountryCode ↔ String?
-
The NationalityCountryCode
getter/setter pair
- optionalData ↔ String?
-
The OptionalData
getter/setter pair
- personalNumber ↔ String?
-
The PersonalNumber
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sex ↔ String?
-
The Sex
getter/setter pair
- surname ↔ String?
-
The Surname
getter/setter pair
- vizAddress ↔ String?
-
The Adress of the Visual Inspection Zone
getter/setter pair
- vizDateOfBirth ↔ String?
-
The DateOfBirth of the Visual Inspection Zone
getter/setter pair
- vizDateOfBirthObject ↔ String?
-
The DateOfBirthObject of the Visual Inspection Zone
getter/setter pair
- vizDateOfExpiry ↔ String?
-
The DateOfExpiry of the Visual Inspection Zone
getter/setter pair
- vizDateOfExpiryObject ↔ String?
-
The DateOfExpiryObject of the Visual Inspection Zone
getter/setter pair
- vizDateOfIssue ↔ String?
-
The DateOfIssue of the Visual Inspection Zone
getter/setter pair
- vizDateOfIssueObject ↔ String?
-
The DateOfIssueObject of the Visual Inspection Zone
getter/setter pair
- vizGivenNames ↔ String?
-
The GivenNames of the Visual Inspection Zone
getter/setter pair
- vizSurname ↔ String?
-
The Surname of the Visual Inspection Zone
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited