OdometerResult class

Describes result information of scanning odometers

Constructors

OdometerResult({String? value})
OdometerResult.fromJson(Map<String, dynamic> json)
factory
OdometerResult.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The odometer value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited