PluginResult class

The plugin-specific scan result produced by the Anyline SDK.

Describes all kinds of scan results

Constructors

PluginResult({BarcodeResult? barcodeResult, String? blobKey, CommercialTireIdResult? commercialTireIdResult, int? confidence, ContainerResult? containerResult, CropRect? cropRect, JapaneseLandingPermissionResult? japaneseLandingPermissionResult, LicensePlateResult? licensePlateResult, MeterResult? meterResult, MrzResult? mrzResult, OcrResult? ocrResult, OdometerResult? odometerResult, PerformanceMetrics? performanceMetrics, String? pluginId, TinResult? tinResult, TireMakeResult? tireMakeResult, TireSizeResult? tireSizeResult, String? transactionId, UniversalIdResult? universalIdResult, VehicleRegistrationCertificateResult? vehicleRegistrationCertificateResult, VinResult? vinResult})
PluginResult.fromJson(Map<String, dynamic> json)
factory
PluginResult.fromRawJson(String str)
factory

Properties

barcodeResult ↔ BarcodeResult?
getter/setter pair
blobKey ↔ String?
The blobKey (provided optionally, depending on the Anyline license settings)
getter/setter pair
commercialTireIdResult ↔ CommercialTireIdResult?
getter/setter pair
confidence ↔ int?
Provides a general confidence value between 0 and 100 if applicable. -1 if no confidence was calculated
getter/setter pair
containerResult ↔ ContainerResult?
getter/setter pair
cropRect ↔ CropRect?
The rect information of the region that was processed within the image
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
japaneseLandingPermissionResult ↔ JapaneseLandingPermissionResult?
getter/setter pair
licensePlateResult ↔ LicensePlateResult?
getter/setter pair
meterResult ↔ MeterResult?
getter/setter pair
mrzResult ↔ MrzResult?
getter/setter pair
ocrResult ↔ OcrResult?
getter/setter pair
odometerResult ↔ OdometerResult?
getter/setter pair
performanceMetrics ↔ PerformanceMetrics?
representing time measurements for different parts of the process.
getter/setter pair
pluginId ↔ String?
The ID of the ScanPlugin that processed the result
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tinResult ↔ TinResult?
getter/setter pair
tireMakeResult ↔ TireMakeResult?
getter/setter pair
tireSizeResult ↔ TireSizeResult?
getter/setter pair
transactionId ↔ String?
A unique UUIDv4 generated for each scan controller process run.
getter/setter pair
universalIdResult ↔ UniversalIdResult?
getter/setter pair
vehicleRegistrationCertificateResult ↔ VehicleRegistrationCertificateResult?
getter/setter pair
vinResult ↔ VinResult?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited