Sfdc class

Constructors

Sfdc({String? accountId, String? accountName, String? oppId})
Sfdc.fromJson(Map<String, dynamic> json)
factory
Sfdc.fromRawJson(String str)
factory

Properties

accountId ↔ String?
getter/setter pair
accountName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oppId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited