TextValues class

Describes the text values of an ID field

Constructors

TextValues({Arabic? arabic, Cyrillic? cyrillic, Latin? latin})
TextValues.fromJson(Map<String, dynamic> json)
factory
TextValues.fromRawJson(String str)
factory

Properties

arabic Arabic?
The text parameters
getter/setter pair
cyrillic Cyrillic?
The text parameters
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latin Latin?
The text parameters
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited