TinResult class

Describes result information of scanning tire identification numbers (TIN)

Constructors

TinResult({String? productionDate, String? resultPrettified, String? text, int? tireAgeInYearsRoundedDown})
TinResult.fromJson(Map<String, dynamic> json)
factory
TinResult.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
productionDate String?
The production date on the TIN reformatted to YYYY/MM.
getter/setter pair
resultPrettified String?
The TIN text split by context with spaces as delimiter.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The TIN text value.
getter/setter pair
tireAgeInYearsRoundedDown int?
The computed tire age in years rounded down.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited