UniversalIdResult class

Describes result information of scanning different kinds of IDs

Constructors

UniversalIdResult({IdResult? result, Visualization? visualization})
UniversalIdResult.fromJson(Map<String, dynamic> json)
factory
UniversalIdResult.fromRawJson(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
result IdResult?
Yields field information of the ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visualization Visualization?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited