UniversalIdResultField class

Describes scanned parameters of an ID field

Constructors

UniversalIdResultField({DateValue? dateValue, TextValues? textValues})
UniversalIdResultField.fromJson(Map<String, dynamic> json)
factory
UniversalIdResultField.fromRawJson(String str)
factory

Properties

dateValue DateValue?
Describes the date value of an ID field
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textValues TextValues?
Describes the text values of an ID field
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited