Visualization class

Information about the visualization data of the scanned ID

Constructors

Visualization({List<List<List<int>>>? contourPoints, List<List<int>>? contours, List<int>? textRect})
Visualization.fromJson(Map<String, dynamic> json)
factory
Visualization.fromRawJson(String str)
factory

Properties

contourPoints List<List<List<int>>>?
The found contour points of the fields on the ID
getter/setter pair
contours List<List<int>>?
The found contours of the fields on the ID
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textRect List<int>?
The found bounding rect of the text fields on the ID
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited