WrapperSessionParameters class

Top-level schema encompassing all request and response types exchanged between the wrapper plugin and the Anyline SDK during a scanning session.

Properties

exportCachedEventsResponse ↔ WrapperSessionExportCachedEventsResponse?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanResponse ↔ WrapperSessionScanResponse?
getter/setter pair
scanResultsResponse ↔ WrapperSessionScanResultsResponse?
getter/setter pair
scanStartRequest ↔ WrapperSessionScanStartRequest?
getter/setter pair
scanStopRequest ↔ WrapperSessionScanStopRequest?
getter/setter pair
scanViewConfigOptions ↔ WrapperSessionScanViewConfigOptions?
getter/setter pair
sdkInitializationRequest ↔ WrapperSessionSdkInitializationRequest?
getter/setter pair
sdkInitializationResponse ↔ WrapperSessionSdkInitializationResponse?
getter/setter pair
ucrReportRequest ↔ WrapperSessionUcrReportRequest?
getter/setter pair
ucrReportResponse ↔ WrapperSessionUcrReportResponse?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited