scanResultConfig property
The result configuration that was active during the completed scan session.
Implementation
WrapperSessionScanResultConfig? scanResultConfig;
The result configuration that was active during the completed scan session.
WrapperSessionScanResultConfig? scanResultConfig;