WrapperSessionScanResponseAbort class

Populated when status is scanAborted. Contains the reason for the abort.

Details about an aborted scan session.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
Optional message provided when the scan session was aborted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited