WrapperSessionScanResponseFail class

Populated when status is scanFailed. Contains the error that caused the failure.

Details about a failed scan session.

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastError ↔ String?
The last error received while trying to scan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited