onResultEventName property
Name of the callback method to invoke when scan results are available. Method will receive a list of ExportedScanResult as parameter.
Implementation
String? onResultEventName;
Name of the callback method to invoke when scan results are available. Method will receive a list of ExportedScanResult as parameter.
String? onResultEventName;