callbackConfig property
Deprecated. Used only by the legacy plugin. Custom callback method names for scan result and UI element click events.
Implementation
WrapperSessionScanResultCallbackConfig? callbackConfig;
Deprecated. Used only by the legacy plugin. Custom callback method names for scan result and UI element click events.
WrapperSessionScanResultCallbackConfig? callbackConfig;