imageContainer property
Specifies how scan result images are delivered — either saved to a file path or encoded as base64 strings.
Implementation
ExportedScanResultImageContainer? imageContainer;
Specifies how scan result images are delivered — either saved to a file path or encoded as base64 strings.
ExportedScanResultImageContainer? imageContainer;