WrapperSessionScanResultsResponse class
Information about the results collected during the scanning process.
Constructors
-
WrapperSessionScanResultsResponse({List<
ExportedScanResult> ? exportedScanResults, WrapperSessionScanResultConfig? scanResultConfig, WrapperSessionScanResultExtraInfo? scanResultExtraInfo}) -
WrapperSessionScanResultsResponse.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanResultsResponse.fromRawJson(String str)
-
factory
Properties
-
exportedScanResults
↔ List<
ExportedScanResult> ? -
List of scan results produced in this scanning event, one per detected item.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanResultConfig ↔ WrapperSessionScanResultConfig?
-
The result configuration that was active when these results were produced.
getter/setter pair
- scanResultExtraInfo ↔ WrapperSessionScanResultExtraInfo?
-
Additional metadata about the source plugin that produced these results.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited