exportedScanResults property
List of scan results produced in this scanning event, one per detected item.
Implementation
List<ExportedScanResult>? exportedScanResults;
List of scan results produced in this scanning event, one per detected item.
List<ExportedScanResult>? exportedScanResults;