scanResultConfig property
The result configuration that was active when these results were produced.
Implementation
WrapperSessionScanResultConfig? scanResultConfig;
The result configuration that was active when these results were produced.
WrapperSessionScanResultConfig? scanResultConfig;