scanResultExtraInfo property
Additional metadata about the source plugin that produced these results.
Implementation
WrapperSessionScanResultExtraInfo? scanResultExtraInfo;
Additional metadata about the source plugin that produced these results.
WrapperSessionScanResultExtraInfo? scanResultExtraInfo;