scanResultConfig property
Configuration for how scan results are returned and stored during the session.
Implementation
WrapperSessionScanResultConfig? scanResultConfig;
Configuration for how scan results are returned and stored during the session.
WrapperSessionScanResultConfig? scanResultConfig;