scanViewConfigPath property
Path relative to the assets folder used to resolve ScanViewConfig JSON files when a SegmentControl references them by filename.
Implementation
String? scanViewConfigPath;
Path relative to the assets folder used to resolve ScanViewConfig JSON files when a SegmentControl references them by filename.
String? scanViewConfigPath;