WrapperSessionScanViewConfigOptionDoneButton class

Deprecated. iOS only. Button that dismisses the scan view. Use toolbarTitle instead.

Deprecated. iOS only. A button that dismisses the scan view screen when pressed. Use toolbarTitle instead.

Constructors

WrapperSessionScanViewConfigOptionDoneButton({String? backgroundColor, double? cornerRadius, FillType? fillType, String? fontName, int? fontSize, double? offsetX, double? offsetY, PositionXAlignment? positionXAlignment, PositionYAlignment? positionYAlignment, String? textColor, String? textColorHighlighted, String? title})
WrapperSessionScanViewConfigOptionDoneButton.fromJson(Map<String, dynamic> json)
factory
WrapperSessionScanViewConfigOptionDoneButton.fromRawJson(String str)
factory

Properties

backgroundColor String?
A color, denoted by a hex string of the button background. The default is empty (clear color).
getter/setter pair
cornerRadius double?
A Float value indicating the corner rounding of the Done button.
getter/setter pair
fillType FillType?
The preset used for width fill.
getter/setter pair
fontName String?
The name of the font (note: the font must be available for the device).
getter/setter pair
fontSize int?
Button title font size in points (typically 8-72).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offsetX double?
getter/setter pair
offsetY double?
getter/setter pair
positionXAlignment PositionXAlignment?
The preset locations for the button along the x-axis.
getter/setter pair
positionYAlignment PositionYAlignment?
The preset locations for the button along the y-axis.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
A color, denoted by a hex string of the button title.
getter/setter pair
textColorHighlighted String?
A color, denoted by a hex string used by the button title when pressed.
getter/setter pair
title String?
The text displayed for the button.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited