WrapperSessionScanViewConfigOptionElementAlignment enum

Corner of the screen where the rotate button is positioned.

Screen corner where the UI element will be positioned. Element will align to the specified corner before applying any offset.

Inheritance
  • Object
  • Enum
  • WrapperSessionScanViewConfigOptionElementAlignment
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WrapperSessionScanViewConfigOptionElementAlignment>
A constant List of the values in this enum, in order of their declaration.