WrapperSessionScanViewConfigOptionElementOffset class

Optional pixel offset from the aligned corner position.

Optional pixel offset from the element's aligned position. Use positive/negative values to fine-tune positioning.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int?
Horizontal offset in pixels. Positive values move the element right, negative values move it left.
getter/setter pair
y int?
Vertical offset in pixels. Positive values move the element down, negative values move it up.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited