alignment property
Corner of the screen where the rotate button is positioned.
Implementation
WrapperSessionScanViewConfigOptionElementAlignment? alignment;
Corner of the screen where the rotate button is positioned.
WrapperSessionScanViewConfigOptionElementAlignment? alignment;