defaultOrientation property
Initial screen orientation when the scan view is presented.
Implementation
WrapperSessionScanViewConfigOptionDefaultOrientation? defaultOrientation;
Initial screen orientation when the scan view is presented.
WrapperSessionScanViewConfigOptionDefaultOrientation? defaultOrientation;