rotateButton property
Optional button that lets users toggle between portrait and landscape orientations.
Implementation
WrapperSessionScanViewConfigOptionRotateButton? rotateButton;
Optional button that lets users toggle between portrait and landscape orientations.
WrapperSessionScanViewConfigOptionRotateButton? rotateButton;