toolbarTitle property
Title shown on the toolbar with a back button. Fullscreen scanning only; ignored when using a ContainerView.
Implementation
String? toolbarTitle;
Title shown on the toolbar with a back button. Fullscreen scanning only; ignored when using a ContainerView.
String? toolbarTitle;