WrapperSessionSdkInitializationCacheConfig class

Optional cache settings applied during initialization.

Cache configuration to be applied on SDK initialization.

Properties

hashCode → int
The hash code for this object.
no setterinherited
offlineLicenseCachingEnabled ↔ bool?
Whether offline license caching is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited