WrapperSessionSdkInitializationResponseInitialized class

Populated when initialized is true. Contains license details from the successful initialization.

Details about a successful SDK initialization.

Properties

expiryDate ↔ String?
License expiry date in ISO 8601 format (YYYY-MM-DD).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited