WrapperSessionSdkInitializationResponseNotInitialized class

Populated when initialized is false. Contains the error that prevented SDK initialization.

Details about a failed SDK initialization attempt.

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastError ↔ String?
The last error received while trying to initialize the SDK.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited