WrapperSessionUcrReportRequest class

Request to submit a User Corrected Result (UCR) for a previously scanned item.

Properties

blobKey ↔ String?
Unique identifier for the scan event, taken from PluginResult.blobKey. Used to correlate the correction with the original scan on the server.
getter/setter pair
correctedResult ↔ String?
The corrected result value to report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited