blobKey property
Unique identifier for the scan event, taken from PluginResult.blobKey. Used to correlate the correction with the original scan on the server.
Implementation
String? blobKey;
Unique identifier for the scan event, taken from PluginResult.blobKey. Used to correlate the correction with the original scan on the server.
String? blobKey;