models/sdk_config library
Classes
- AllowedLayouts
- Specifies the document types to be scanned and optionally further specifies which types of layout are scanned per type.
- BarcodeConfig
- Configuration for scanning barcodes
- CameraConfig
- Schema for SDK Camera Configuration
- CommercialTireIdConfig
- Configuration for scanning commercial Tire IDs
- ContainerConfig
- Configuration for scanning shipping container numbers
- CutoutConfig
- Schema for SDK Cutout Configuration
-
EnumValues<
T> - FlashConfig
- Schema for SDK Flash Configuration
- JapaneseLandingPermissionConfig
- Configuration for scanning japanese landing permission tickets
- JapaneseLandingPermissionConfigFieldOption
- Field option for JLP fields
- LayoutDrivingLicense
- Contains all the supported field scan options for driving licenses.
- LayoutIdFront
- Contains all the supported field scan options for ID front cards.
- LayoutInsuranceCard
- Contains all the supported field scan options for insurance cards.
- LayoutMrz
- Contains all the supported field scan options for MRZ.
- LayoutVehicleRegistrationCertificate
- Contains all the supported field scan options for vehicle registration certificates.
- LicensePlateConfig
- Configuration for scanning license plates
- MeterConfig
- Configuration for scanning meters
- MrzConfig
- Configuration for scanning machine-readable zones (MRZ) of passports and other IDs
- MrzFieldScanOptions
- The fieldmrzScanOptions configure which text fields shall be captured mandatory, optional or not at all.
- MrzMinFieldConfidences
- The minFieldConfidences configure which fields must reach which confidence thresholds in order to be part of the scan result.
- NonNegativeOffset
- Expands the captured image region beyond the cutout in camera pixels (px). Non-negative values only — negative values will cause a runtime exception. Example: cutout width=700px with padding={x:10} → 720px captured.
- OcrConfig
- Configuration for general OCR scanning use-cases
- OdometerConfig
- Configuration for scanning odometers
- Offset
- An optional position offset for the flash button in density-independent pixels (dp).
- OverlayConfig
- Configuration for UI Feedback overlays
- OverlayDimensionConfig
- Sets the offset dimension of the overlay.
- OverlayScaleConfig
- Sets the scale for x axis of the overlay.
- PluginConfig
- General configuration for scan plugins
- RatioFromSize
- A size constraining the ratio of width / height. If set to 0, the ratio will be equal to the full frame. For the optimal ratio for each technical capability have a look at the Technical Capabilities section at documentation.anyline.com.
- RunSkippedWhen
- Configuration for triggering UI Feedback on RunSkipped events
- ScanFeedbackConfig
- Schema for SDK ScanFeedback Configuration
- ScanInfoWhen
- Configuration for triggering UI Feedback on ScanInfo events
- ScanViewConfiguration
- Schema for SDK JSON configurations
- StartVariable
- Describes a start variable for fine-tuning plugins.
- TinConfig
- Configuration for scanning TIN numbers
- TireMakeConfig
- Configuration for scanning Tire Makes
- TireSizeConfig
- Configuration for scanning Tire Size Specifications
- UiFeedbackConfig
- General configuration for UI Feedback elements
- UiFeedbackElementAttributesConfig
- Configuration attributes for UI Feedback view elements
- UiFeedbackElementConfig
- Configuration for uiFeedback element
- UiFeedbackElementContentConfig
- Configuration for UI Feedback content
- UiFeedbackElementTriggerConfig
- Trigger configuration for UI Feedback
- UiFeedbackElementTriggerWhenRunSkippedConfig
- Configuration for triggering UI Feedback on RunSkipped events
- UiFeedbackElementTriggerWhenScanInfoConfig
- Configuration for triggering UI Feedback on ScanInfo events
- UiFeedbackPresetAttributeConfig
- Configuration for uiFeedback preset attribute.
- UiFeedbackPresetConfig
- Configuration for uiFeedback preset.
- UiFeedbackPresetContentConfig
- Configuration for uiFeedback preset content definition.
- UiFeedbackPresetDefinitionAttributeConfig
- Configuration for uiFeedback preset definition attribute.
- UiFeedbackPresetDefinitionConfig
- Configuration for uiFeedback preset definition.
- UniversalIdConfig
- Configuration for scanning all kinds of identification documents
- UniversalIdField
- Configures scanning options for ID fields in order to fine-tune the ID scanner.
- VehicleRegistrationCertificateConfig
- Configuration for scanning Vehicle Registration Certificates
- VehicleRegistrationCertificateField
- The Address Field
- ViewPlugin
- ViewPluginCompositeConfig
- Schema for SDK ViewPlugin Configuration
- ViewPluginConfig
- Schema for SDK ViewPlugin Configuration
- VinConfig
- Configuration for scanning vehicle identification numbers (VIN)
Enums
- Alphabet
- Sets a specific character set.
- BarcodeFormat
- ContainerConfigScanMode
- Determines if container numbers shall be scanned horizontally or vertically.
- ContentTypeEnum
- Sets the view type of the element.
- CutoutConfigAlignment
- The alignment of the cutout area.
- CutoutConfigAnimation
- Animation type for the cutout when initially displayed. Values: none, fade, zoom
- ElementTypeEnum
- Sets the preset definition attribute element type.
- FlashConfigAlignment
- The alignment of the flash button.
- ImageScaleType
- Sets the image scale type.
- LicensePlateConfigScanMode
- Specifies a country or location of which license plates shall be scanned.
- MeterConfigScanMode
- Determines which types of meters to scan.
- Mode
- The flash mode.
- MrzScanOption
- The scanOption determines whether a field is considered optional, mandatory, disabled or follows a default behavior. Default behavior is one of the other three that yields the best recall results with all layouts enabled.
- OcrConfigScanMode
- Sets whether to scan single-line texts, multi-line texts in a grid-formation or finds text automatically.
- OverlayAnchorConfig
- Sets the anchor of the overlay.
- OverlayScaleTypeConfig
- Sets the scale type of the overlay.
- OverlaySource
- Sets the source of the overlay.
- ProcessingMode
- The processing mode of the workflow (parallel, sequential, parallelFirstScan).
- ScanFeedbackConfigAnimation
- The animation style of the feedback.
- Style
- The style of the feedback.
- TextAlignment
- Sets the text alignment.
- TinConfigScanMode
- Sets the mode to scan universal TIN numbers ('UNIVERSAL') or TIN numbers of any length starting with DOT ('DOT').
- Type
- Sets the preset definition type.
- UpsideDownMode
- Sets whether the text shall also be scanned upside-down.
- VehicleInspectionSticker
- Select if the visual inspection sticker should be scanned. If OPTIONAL, the visual inspection sticker will only be returned if found successfully. If MANDATORY the scan will only return if found successfully. Not available on africa and unitedstates.
Properties
-
alphabetValues
→ EnumValues<
Alphabet> -
final
-
barcodeFormatValues
→ EnumValues<
BarcodeFormat> -
final
-
containerConfigScanModeValues
→ EnumValues<
ContainerConfigScanMode> -
final
-
contentTypeEnumValues
→ EnumValues<
ContentTypeEnum> -
final
-
cutoutConfigAlignmentValues
→ EnumValues<
CutoutConfigAlignment> -
final
-
cutoutConfigAnimationValues
→ EnumValues<
CutoutConfigAnimation> -
final
-
elementTypeEnumValues
→ EnumValues<
ElementTypeEnum> -
final
-
flashConfigAlignmentValues
→ EnumValues<
FlashConfigAlignment> -
final
-
imageScaleTypeValues
→ EnumValues<
ImageScaleType> -
final
-
licensePlateConfigScanModeValues
→ EnumValues<
LicensePlateConfigScanMode> -
final
-
meterConfigScanModeValues
→ EnumValues<
MeterConfigScanMode> -
final
-
modeValues
→ EnumValues<
Mode> -
final
-
mrzScanOptionValues
→ EnumValues<
MrzScanOption> -
final
-
ocrConfigScanModeValues
→ EnumValues<
OcrConfigScanMode> -
final
-
overlayAnchorConfigValues
→ EnumValues<
OverlayAnchorConfig> -
final
-
overlayScaleTypeConfigValues
→ EnumValues<
OverlayScaleTypeConfig> -
final
-
overlaySourceValues
→ EnumValues<
OverlaySource> -
final
-
processingModeValues
→ EnumValues<
ProcessingMode> -
final
-
scanFeedbackConfigAnimationValues
→ EnumValues<
ScanFeedbackConfigAnimation> -
final
-
styleValues
→ EnumValues<
Style> -
final
-
textAlignmentValues
→ EnumValues<
TextAlignment> -
final
-
tinConfigScanModeValues
→ EnumValues<
TinConfigScanMode> -
final
-
typeValues
→ EnumValues<
Type> -
final
-
upsideDownModeValues
→ EnumValues<
UpsideDownMode> -
final
-
vehicleInspectionStickerValues
→ EnumValues<
VehicleInspectionSticker> -
final