BarcodeConfig class
Configuration for scanning barcodes
Constructors
-
BarcodeConfig({List<
BarcodeFormat> ? barcodeFormats, bool? consecutiveEqualResults, bool? disableAdvancedBarcode, bool? fastProcessMode, bool? multiBarcode, bool? parseAamva}) -
BarcodeConfig.fromJson(Map<
String, dynamic> json) -
factory
- BarcodeConfig.fromRawJson(String str)
-
factory
Properties
-
barcodeFormats
↔ List<
BarcodeFormat> ? -
Set this to filter which barcode formats should be scanned. Setting 'ALL' will enable
scanning all supported formats.
getter/setter pair
- consecutiveEqualResults ↔ bool?
-
DEPRECATEDIf this option is set, allows consecutive barcode results of the same barcode when scanning continuously.getter/setter pair - disableAdvancedBarcode ↔ bool?
-
Sets whether or not to disable advanced barcode scanning even if the license supports it.
getter/setter pair
- fastProcessMode ↔ bool?
-
If this option is set, uses faster image processing for barcode scanning. Note:
fastProcessMode is not available during composite scanning.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- multiBarcode ↔ bool?
-
Setting this to 'true' will enable reading multiple barcodes per frame.
getter/setter pair
- parseAamva ↔ bool?
-
If this option is set, barcodes parsed according to the AAMVA standard. This only works
for PDF417 codes on driving licenses.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited