consecutiveEqualResults property
DEPRECATED If this option is set, allows consecutive barcode results of the same
barcode when scanning continuously.
Implementation
bool? consecutiveEqualResults;
DEPRECATED If this option is set, allows consecutive barcode results of the same
barcode when scanning continuously.
bool? consecutiveEqualResults;