enableFlipFramesTopBottom property
(EXPERIMENTAL; Android-only) Turns the frame upside down (top-bottom) before it is processed, equivalent to a vertical flip along the horizontal axis. The camera preview on the screen is not affected. Disabled by default. NOTE: This has no effect when pluginConfig.barcodeConfig.fastProcessMode is true.
Implementation
bool? enableFlipFramesTopBottom;