FlashConfig class
Schema for SDK Flash Configuration
Constructors
- FlashConfig({FlashConfigAlignment? alignment, String? imageAuto, String? imageOff, String? imageOn, Mode? mode, Offset? offset})
-
FlashConfig.fromJson(Map<
String, dynamic> json) -
factory
- FlashConfig.fromRawJson(String str)
-
factory
Properties
- alignment ↔ FlashConfigAlignment?
-
The alignment of the flash button.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageAuto ↔ String?
-
The asset name of the icon to be displayed when the flash is set to auto.
getter/setter pair
- imageOff ↔ String?
-
The asset name of the icon to be displayed when the flash is off.
getter/setter pair
- imageOn ↔ String?
-
The asset name of the icon to be displayed when the flash is on.
getter/setter pair
- mode ↔ Mode?
-
The flash mode.
getter/setter pair
- offset ↔ Offset?
-
An optional position offset for the flash button in density-independent pixels (dp).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited