LayoutMrz class
Contains all the supported field scan options for MRZ.
Constructors
- LayoutMrz({UniversalIdField? dateOfBirth, UniversalIdField? dateOfExpiry, UniversalIdField? vizAddress, UniversalIdField? vizDateOfBirth, UniversalIdField? vizDateOfExpiry, UniversalIdField? vizDateOfIssue, UniversalIdField? vizGivenNames, UniversalIdField? vizSurname})
-
LayoutMrz.fromJson(Map<
String, dynamic> json) -
factory
- LayoutMrz.fromRawJson(String str)
-
factory
Properties
- dateOfBirth ↔ UniversalIdField?
-
getter/setter pair
- dateOfExpiry ↔ UniversalIdField?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vizAddress ↔ UniversalIdField?
-
getter/setter pair
- vizDateOfBirth ↔ UniversalIdField?
-
getter/setter pair
- vizDateOfExpiry ↔ UniversalIdField?
-
getter/setter pair
- vizDateOfIssue ↔ UniversalIdField?
-
getter/setter pair
- vizGivenNames ↔ UniversalIdField?
-
getter/setter pair
- vizSurname ↔ UniversalIdField?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited