vehicleInspectionSticker property
Select if the visual inspection sticker should be scanned. If OPTIONAL, the visual inspection sticker will only be returned if found successfully. If MANDATORY the scan will only return if found successfully. Not available on africa and unitedstates.
Implementation
VehicleInspectionSticker? vehicleInspectionSticker;