LicensePlateConfigScanMode enum
Specifies a country or location of which license plates shall be scanned.
Values
- AFRICA → const LicensePlateConfigScanMode
- ALBANIA → const LicensePlateConfigScanMode
- ANDORRA → const LicensePlateConfigScanMode
- ARMENIA → const LicensePlateConfigScanMode
- AUSTRIA → const LicensePlateConfigScanMode
- AUTO → const LicensePlateConfigScanMode
- AZERBAIJAN → const LicensePlateConfigScanMode
- BELARUS → const LicensePlateConfigScanMode
- BELGIUM → const LicensePlateConfigScanMode
- BOSNIAANDHERZEGOVINA → const LicensePlateConfigScanMode
- BULGARIA → const LicensePlateConfigScanMode
- CANADA → const LicensePlateConfigScanMode
- CROATIA → const LicensePlateConfigScanMode
- CYPRUS → const LicensePlateConfigScanMode
- CZECH → const LicensePlateConfigScanMode
- DENMARK → const LicensePlateConfigScanMode
- ESTONIA → const LicensePlateConfigScanMode
- FINLAND → const LicensePlateConfigScanMode
- FRANCE → const LicensePlateConfigScanMode
- GEORGIA → const LicensePlateConfigScanMode
- GERMANY → const LicensePlateConfigScanMode
- GREECE → const LicensePlateConfigScanMode
- HUNGARY → const LicensePlateConfigScanMode
- ICELAND → const LicensePlateConfigScanMode
- IRELAND → const LicensePlateConfigScanMode
- ITALY → const LicensePlateConfigScanMode
- LATVIA → const LicensePlateConfigScanMode
- LIECHTENSTEIN → const LicensePlateConfigScanMode
- LITHUANIA → const LicensePlateConfigScanMode
- LUXEMBOURG → const LicensePlateConfigScanMode
- MALTA → const LicensePlateConfigScanMode
- MOLDOVA → const LicensePlateConfigScanMode
- MONACO → const LicensePlateConfigScanMode
- MONTENEGRO → const LicensePlateConfigScanMode
- NETHERLANDS → const LicensePlateConfigScanMode
- NORTHMACEDONIA → const LicensePlateConfigScanMode
- NORWAY → const LicensePlateConfigScanMode
- NORWAYSPECIAL → const LicensePlateConfigScanMode
- POLAND → const LicensePlateConfigScanMode
- PORTUGAL → const LicensePlateConfigScanMode
- ROMANIA → const LicensePlateConfigScanMode
- RUSSIA → const LicensePlateConfigScanMode
- SERBIA → const LicensePlateConfigScanMode
- SLOVAKIA → const LicensePlateConfigScanMode
- SLOVENIA → const LicensePlateConfigScanMode
- SPAIN → const LicensePlateConfigScanMode
- SWEDEN → const LicensePlateConfigScanMode
- SWITZERLAND → const LicensePlateConfigScanMode
- TURKEY → const LicensePlateConfigScanMode
- UKRAINE → const LicensePlateConfigScanMode
- UNITEDKINGDOM → const LicensePlateConfigScanMode
- UNITEDSTATES → const LicensePlateConfigScanMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LicensePlateConfigScanMode> - A constant List of the values in this enum, in order of their declaration.