MrzConfig class
Configuration for scanning machine-readable zones (MRZ) of passports and other IDs
Constructors
- MrzConfig({bool? cropAndTransformId, bool? faceDetectionEnabled, int? minConfidence, MrzFieldScanOptions? mrzFieldScanOptions, MrzMinFieldConfidences? mrzMinFieldConfidences, bool? strictMode})
-
MrzConfig.fromJson(Map<
String, dynamic> json) -
factory
- MrzConfig.fromRawJson(String str)
-
factory
Properties
- cropAndTransformId ↔ bool?
-
The cropAndTransformID determines whether or not the image shall be cropped and
transformed.
getter/setter pair
- faceDetectionEnabled ↔ bool?
-
Sets whether the face detection approach is enabled.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- minConfidence ↔ int?
-
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
- mrzFieldScanOptions ↔ MrzFieldScanOptions?
-
The fieldmrzScanOptions configure which text fields shall be captured mandatory, optional
or not at all.
getter/setter pair
- mrzMinFieldConfidences ↔ MrzMinFieldConfidences?
-
The minFieldConfidences configure which fields must reach which confidence thresholds in
order to be part of the scan result.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strictMode ↔ bool?
-
When enabling the strictMode, a result is only returned if all the check digits on the
scanned document are valid.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited