strictMode property
When enabling the strictMode, a result is only returned if all the check digits on the scanned document are valid.
Implementation
bool? strictMode;
When enabling the strictMode, a result is only returned if all the check digits on the scanned document are valid.
bool? strictMode;