customCmdFile property
Sets a custom Anyline script. The file has to be located in the project and point to a path relative from the project root. Please check the official documentation for more details.
Implementation
String? customCmdFile;
Sets a custom Anyline script. The file has to be located in the project and point to a path relative from the project root. Please check the official documentation for more details.
String? customCmdFile;