Offset class
An optional position offset for the flash button in density-independent pixels (dp).
An x/y integer value pair. The unit (dp or camera pixels) depends on the property that references this definition.
Adjusts the captured region position in camera pixels (px) after cropPadding is applied. Positive x shifts right, positive y shifts down.
Position offset of the cutout in camera pixels (px), used in conjunction with alignment.
Constructors
- Offset({int? x, int? y})
-
Offset.fromJson(Map<
String, dynamic> json) -
factory
- Offset.fromRawJson(String str)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited