OverlayConfig class
Configuration for UI Feedback overlays
Constructors
-
OverlayConfig({OverlayAnchorConfig? anchor, OverlayDimensionConfig? offsetDimension, List<
UiFeedbackPresetConfig> ? presets, OverlayDimensionConfig? sizeDimension, OverlaySource? source}) -
OverlayConfig.fromJson(Map<
String, dynamic> json) -
factory
- OverlayConfig.fromRawJson(String str)
-
factory
Properties
- anchor ↔ OverlayAnchorConfig?
-
Sets the anchor of the overlay.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- offsetDimension ↔ OverlayDimensionConfig?
-
Sets the offset dimension of the overlay.
getter/setter pair
-
presets
↔ List<
UiFeedbackPresetConfig> ? -
Allows to use overlay presets.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeDimension ↔ OverlayDimensionConfig?
-
Sets the size dimension of the overlay.
getter/setter pair
- source ↔ OverlaySource?
-
Sets the source of the overlay.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited