RatioFromSize class
A size constraining the ratio of width / height. If set to 0, the ratio will be equal to the full frame. For the optimal ratio for each technical capability have a look at the Technical Capabilities section at documentation.anyline.com.
Constructors
- RatioFromSize({double? height, double? width})
-
RatioFromSize.fromJson(Map<
String, dynamic> json) -
factory
- RatioFromSize.fromRawJson(String str)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited