validateProductionDate property
Sets whether the production date validation is enabled. If it is set to false the scan result is also returned for invalid and missing dates.
Implementation
bool? validateProductionDate;
Sets whether the production date validation is enabled. If it is set to false the scan result is also returned for invalid and missing dates.
bool? validateProductionDate;