TireMakeConfig class
Configuration for scanning Tire Makes
Constructors
- TireMakeConfig({int? minConfidence, UpsideDownMode? upsideDownMode, String? validationRegex})
-
TireMakeConfig.fromJson(Map<
String, dynamic> json) -
factory
- TireMakeConfig.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minConfidence ↔ int?
-
Sets a minimum confidence which has to be reached in order to trigger a scan result.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upsideDownMode ↔ UpsideDownMode?
-
Sets whether the text shall also be scanned upside-down.
getter/setter pair
- validationRegex ↔ String?
-
Sets a regular expression which the tire make text needs to match in order to trigger a
scan result. E.g. "(Continental|Dunlop)" will only trigger on Continental or Dunlop tires.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited