UniversalIdConfig class
Configuration for scanning all kinds of identification documents
Constructors
- UniversalIdConfig({AllowedLayouts? allowedLayouts, Alphabet? alphabet, LayoutDrivingLicense? drivingLicense, bool? faceDetectionEnabled, LayoutIdFront? idFront, LayoutInsuranceCard? insuranceCard, LayoutMrz? mrz})
-
UniversalIdConfig.fromJson(Map<
String, dynamic> json) -
factory
- UniversalIdConfig.fromRawJson(String str)
-
factory
Properties
- allowedLayouts ↔ AllowedLayouts?
-
Specifies the document types to be scanned and optionally further specifies which types
of layout are scanned per type.
getter/setter pair
- alphabet ↔ Alphabet?
-
Sets a specific character set.
getter/setter pair
- drivingLicense ↔ LayoutDrivingLicense?
-
getter/setter pair
- faceDetectionEnabled ↔ bool?
-
Sets whether the face detection approach is enabled.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- idFront ↔ LayoutIdFront?
-
getter/setter pair
- insuranceCard ↔ LayoutInsuranceCard?
-
getter/setter pair
- mrz ↔ LayoutMrz?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited