VehicleInspectionSticker enum
Select if the visual inspection sticker should be scanned. If OPTIONAL, the visual inspection sticker will only be returned if found successfully. If MANDATORY the scan will only return if found successfully. Not available on africa and unitedstates.
Values
- DISABLED → const VehicleInspectionSticker
- MANDATORY → const VehicleInspectionSticker
- OPTIONAL → const VehicleInspectionSticker
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VehicleInspectionSticker> - A constant List of the values in this enum, in order of their declaration.