VehicleRegistrationCertificateField class
The Address Field
Configures scanning options per field
The Brand Field
The Displacement Field
The DocumentNumber Field
The FirstIssued Field
The FirstName Field
The LastName Field
The LicensePlate Field
The ManufacturerCode Field
The Tire Field
The VehicleIdentificationNumber Field
The VehicleType Field
The VehicleTypeCode Field
Constructors
- VehicleRegistrationCertificateField({int? minConfidence, MrzScanOption? scanOption})
-
VehicleRegistrationCertificateField.fromJson(Map<
String, dynamic> json) -
factory
- VehicleRegistrationCertificateField.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minConfidence ↔ int?
-
Set the minConfidence between 0 and 100. Otherwise, it's defaulted.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanOption ↔ MrzScanOption?
-
The scanOption determines whether a field is considered optional, mandatory, disabled or
follows a default behavior. Default behavior is one of the other three that yields the
best recall results with all layouts enabled.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited