ViewPluginConfig class
Schema for SDK ViewPlugin Configuration
Constructors
- ViewPluginConfig({CutoutConfig? cutoutConfig, PluginConfig? pluginConfig, ScanFeedbackConfig? scanFeedbackConfig, UiFeedbackConfig? uiFeedbackConfig})
-
ViewPluginConfig.fromJson(Map<
String, dynamic> json) -
factory
- ViewPluginConfig.fromRawJson(String str)
-
factory
Properties
- cutoutConfig ↔ CutoutConfig?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pluginConfig ↔ PluginConfig?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanFeedbackConfig ↔ ScanFeedbackConfig?
-
getter/setter pair
- uiFeedbackConfig ↔ UiFeedbackConfig?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited