VinConfig class
Configuration for scanning vehicle identification numbers (VIN)
Constructors
- VinConfig({String? charWhitelist, bool? validateCheckDigit, String? validationRegex})
-
VinConfig.fromJson(Map<
String, dynamic> json) -
factory
- VinConfig.fromRawJson(String str)
-
factory
Properties
- charWhitelist ↔ String?
-
Restricts the scanner to a set of characters to be detected.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateCheckDigit ↔ bool?
-
Setting this to 'true' will enforce checking the check digit and only return results if
it is correct.
getter/setter pair
- validationRegex ↔ String?
-
Sets a regular expression which the scanned text needs to match in order to trigger a
scan result.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited