Demo class
Data contained within the QR code that's required to unlock scanning with the Showcase Apps.
Constructors
- Demo({int? qrVersion, Sfdc? sfdc, String? validityDate})
-
Demo.fromJson(Map<
String, dynamic> json) -
factory
- Demo.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qrVersion ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sfdc ↔ Sfdc?
-
getter/setter pair
- validityDate ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited