ExportedScanResultImageContainer class
Specifies how scan result images are delivered — either saved to a file path or encoded as base64 strings.
Specifies how and where the scan result images are delivered.
Specifies how and where scan result images are delivered. Use saved to store images to disk, or encoded to receive them as base64 strings in the result.
Constructors
- ExportedScanResultImageContainer({ExportedScanResultImageContainerEncoded? encoded, ExportedScanResultImageContainerSaved? saved})
-
ExportedScanResultImageContainer.fromJson(Map<
String, dynamic> json) -
factory
- ExportedScanResultImageContainer.fromRawJson(String str)
-
factory
Properties
- encoded ↔ ExportedScanResultImageContainerEncoded?
-
Deliver images as base64-encoded strings embedded in the result JSON.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saved ↔ ExportedScanResultImageContainerSaved?
-
Deliver images as files saved to the specified directory path.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited