ExportedScanResultImageParameters class
Output format and quality settings for scan result images.
Output format and quality settings applied to all images exported with this scan result.
Constructors
- ExportedScanResultImageParameters({ExportedScanResultImageFormat? format, int? quality})
-
ExportedScanResultImageParameters.fromJson(Map<
String, dynamic> json) -
factory
- ExportedScanResultImageParameters.fromRawJson(String str)
-
factory
Properties
- format ↔ ExportedScanResultImageFormat?
-
Image format used when exporting scan result images.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality ↔ int?
-
Compression quality for exported images, from 1 (lowest) to 100 (highest).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited