ExportedScanResultImages class
The base64-encoded image data for each image type.
References to the images captured during scanning. Each field is a file path (saved container) or base64 string (encoded container). Fields are only populated for image types the active plugin produces.
The image filenames saved in the specified path.
Constructors
- ExportedScanResultImages({String? cutoutImage, String? faceImage, String? image})
-
ExportedScanResultImages.fromJson(Map<
String, dynamic> json) -
factory
- ExportedScanResultImages.fromRawJson(String str)
-
factory
Properties
- cutoutImage ↔ String?
-
The cropped cutout image corresponding to the scanned region.
getter/setter pair
- faceImage ↔ String?
-
The face image extracted from the scanned document, if available.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- image ↔ String?
-
The full frame image captured at the moment of the scan result.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited