MeterResult class
Describes result information of scanning meters
Constructors
- MeterResult({String? position, String? unit, String? value})
-
MeterResult.fromJson(Map<
String, dynamic> json) -
factory
- MeterResult.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ String?
-
The position. Only applicable for OBIS meters - see https://onemeter.com/docs/device/obis/
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit ↔ String?
-
The unit value. Only applicable for multi-field meter scanning.
getter/setter pair
- value ↔ String?
-
The meter value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited