ScanViewInitializationParameters class
Optional initialization parameters applied when the ScanView is created.
Schema for ScanView JSON initialization parameters
Constructors
- ScanViewInitializationParameters({String? correlationId, Demo? demo})
-
ScanViewInitializationParameters.fromJson(Map<
String, dynamic> json) -
factory
- ScanViewInitializationParameters.fromRawJson(String str)
-
factory
Properties
- correlationId ↔ String?
-
An optional uuid (v4) to correlate scans and data points within a workflow.
getter/setter pair
- demo ↔ Demo?
-
Data contained within the QR code that's required to unlock scanning with the Showcase
Apps.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited