WrapperSessionExportCachedEventsResponse class

Response from cached events export operation. Includes either failInfo (if export failed) or succeedInfo (if successful), corresponding to the status field.

Properties

failInfo WrapperSessionExportCachedEventsResponseFail?
Populated when status is exportFailed. Contains the error that caused the failure.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WrapperSessionExportCachedEventsResponseStatus?
The final status of the export operation.
getter/setter pair
succeedInfo WrapperSessionExportCachedEventsResponseSucceed?
Populated when status is exportSucceeded. Contains the path to the exported file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited