WrapperSessionExportCachedEventsResponseSucceed class
Populated when status is exportSucceeded. Contains the path to the exported file.
Details about a successful cached events export.
Constructors
- WrapperSessionExportCachedEventsResponseSucceed({String? exportedFile})
-
WrapperSessionExportCachedEventsResponseSucceed.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionExportCachedEventsResponseSucceed.fromRawJson(String str)
-
factory
Properties
- exportedFile ↔ String?
-
Path to the generated file containing the exported cached events.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited