WrapperSessionScanResponse class
Response indicating scan session completion status. Includes exactly one info object (failInfo, abortInfo, or succeedInfo) corresponding to the status field value.
Constructors
- WrapperSessionScanResponse({WrapperSessionScanResponseAbort? abortInfo, WrapperSessionScanResponseFail? failInfo, WrapperSessionScanResultConfig? scanResultConfig, WrapperSessionScanResponseStatus? status, WrapperSessionScanResponseSucceed? succeedInfo})
-
WrapperSessionScanResponse.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanResponse.fromRawJson(String str)
-
factory
Properties
- abortInfo ↔ WrapperSessionScanResponseAbort?
-
Populated when status is scanAborted. Contains the reason for the abort.
getter/setter pair
- failInfo ↔ WrapperSessionScanResponseFail?
-
Populated when status is scanFailed. Contains the error that caused the failure.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanResultConfig ↔ WrapperSessionScanResultConfig?
-
The result configuration that was active during the completed scan session.
getter/setter pair
- status ↔ WrapperSessionScanResponseStatus?
-
The final status of the scan session.
getter/setter pair
- succeedInfo ↔ WrapperSessionScanResponseSucceed?
-
Populated when status is scanSucceeded. Contains an optional completion message.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited