WrapperSessionScanResultCallbackConfig class
Deprecated. Used only by the legacy plugin. Custom callback method names for scan result and UI element click events.
Deprecated. Used only by the legacy plugin. Configuration for callback method names invoked during scanning events.
Constructors
- WrapperSessionScanResultCallbackConfig({String? onResultEventName, String? onUiElementClickedEventName})
-
WrapperSessionScanResultCallbackConfig.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanResultCallbackConfig.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onResultEventName ↔ String?
-
Name of the callback method to invoke when scan results are available. Method will
receive a list of ExportedScanResult as parameter.
getter/setter pair
- onUiElementClickedEventName ↔ String?
-
Name of the callback method to invoke when user taps a UI feedback element during
scanning. Method receives a UIFeedbackElementConfig as parameter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited