WrapperSessionScanStartRequest class
Request to start a scanning session. Requires both scanViewConfigContentString (defining what to scan) and scanResultConfig (defining how to handle results). Optional scanViewInitializationParameters for workflow correlation.
Constructors
- WrapperSessionScanStartRequest({WrapperSessionScanStartPlatformOptions? platformOptions, WrapperSessionScanResultConfig? scanResultConfig, String? scanViewConfigContentString, String? scanViewConfigPath, ScanViewInitializationParameters? scanViewInitializationParameters})
-
WrapperSessionScanStartRequest.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanStartRequest.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platformOptions ↔ WrapperSessionScanStartPlatformOptions?
-
Platform-specific options applied when starting a scan session.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanResultConfig ↔ WrapperSessionScanResultConfig?
-
Configuration for how scan results are returned and stored during the session.
getter/setter pair
- scanViewConfigContentString ↔ String?
-
ScanViewConfig JSON string defining the scanner configuration.
getter/setter pair
- scanViewConfigPath ↔ String?
-
Path relative to the assets folder used to resolve ScanViewConfig JSON files when a
SegmentControl references them by filename.
getter/setter pair
- scanViewInitializationParameters ↔ ScanViewInitializationParameters?
-
Optional initialization parameters applied when the ScanView is created.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited