WrapperSessionScanViewConfigOptionLabel class
Deprecated. iOS only. Static text label on the scan view. Use the Simple Instruction Label UI Feedback preset instead.
Deprecated. iOS only. A static text label displayed on the scan view. Use the Simple Instruction Label UI Feedback preset instead.
Constructors
- WrapperSessionScanViewConfigOptionLabel({String? color, double? offsetX, double? offsetY, int? size, String? text})
-
WrapperSessionScanViewConfigOptionLabel.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanViewConfigOptionLabel.fromRawJson(String str)
-
factory
Properties
- color ↔ String?
-
Hex color string for the label text.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- offsetX ↔ double?
-
getter/setter pair
- offsetY ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int?
-
The font size of the label.
getter/setter pair
- text ↔ String?
-
The text to display.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited