WrapperSessionScanViewConfigOptionRotateButton class
Optional button that lets users toggle between portrait and landscape orientations.
Button that toggles between portrait and landscape orientations when tapped. Positioned according to alignment and optional offset settings.
Constructors
- WrapperSessionScanViewConfigOptionRotateButton({WrapperSessionScanViewConfigOptionElementAlignment? alignment, WrapperSessionScanViewConfigOptionElementOffset? offset})
-
WrapperSessionScanViewConfigOptionRotateButton.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionScanViewConfigOptionRotateButton.fromRawJson(String str)
-
factory
Properties
- alignment ↔ WrapperSessionScanViewConfigOptionElementAlignment?
-
Corner of the screen where the rotate button is positioned.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset ↔ WrapperSessionScanViewConfigOptionElementOffset?
-
Optional pixel offset from the aligned corner position.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited