titleIndex property
Zero-based index indicating which segment should be initially selected. Must be within the bounds of the titles array.
Implementation
int? titleIndex;
Zero-based index indicating which segment should be initially selected. Must be within the bounds of the titles array.
int? titleIndex;