WrapperSessionSdkInitializationRequest class
General information to be used for SDK initialization.
Constructors
- WrapperSessionSdkInitializationRequest({String? assetPathPrefix, WrapperSessionSdkInitializationCacheConfig? cacheConfig, String? licenseKey})
-
WrapperSessionSdkInitializationRequest.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionSdkInitializationRequest.fromRawJson(String str)
-
factory
Properties
- assetPathPrefix ↔ String?
-
Root folder path the SDK uses when resolving asset files. Leave empty to use the default
asset location.
getter/setter pair
- cacheConfig ↔ WrapperSessionSdkInitializationCacheConfig?
-
Optional cache settings applied during initialization.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- licenseKey ↔ String?
-
Anyline license key to be used for SDK initialization.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited