WrapperSessionSdkInitializationResponse class

Response containing SDK initialization result. Must include either failInfo (if initialization failed) or succeedInfo (if successful). The 'initialized' boolean indicates the overall status.

Properties

failInfo WrapperSessionSdkInitializationResponseNotInitialized?
Populated when initialized is false. Contains the error that prevented SDK initialization.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialized bool?
True if SDK initialization succeeded and scanning is available, false if initialization failed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
succeedInfo WrapperSessionSdkInitializationResponseInitialized?
Populated when initialized is true. Contains license details from the successful initialization.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited