WrapperSessionUcrReportResponse class

Response from UCR (User Corrected Result) reporting. Must include either failInfo (if reporting failed) or succeedInfo (if successful), corresponding to the status field.

Properties

failInfo WrapperSessionUcrReportResponseFail?
Populated when status is ucrReportFailed. Contains the error details.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WrapperSessionUcrReportResponseStatus?
The final status of the UCR report submission.
getter/setter pair
succeedInfo WrapperSessionUcrReportResponseSucceed?
Populated when status is ucrReportSucceeded. Contains the server confirmation message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited