WrapperSessionUcrReportResponseFail class
Populated when status is ucrReportFailed. Contains the error details.
Details about a failed UCR report submission.
Constructors
- WrapperSessionUcrReportResponseFail({String? lastError, int? responseErrorCode, String? responseErrorMessage})
-
WrapperSessionUcrReportResponseFail.fromJson(Map<
String, dynamic> json) -
factory
- WrapperSessionUcrReportResponseFail.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastError ↔ String?
-
The last error received while reporting UCR.
getter/setter pair
- responseErrorCode ↔ int?
-
The error code received while connecting to server.
getter/setter pair
- responseErrorMessage ↔ String?
-
The error message received while connecting to server.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited